@@ -37,6 +37,11 @@ class SkillsNetworkAuthoringExtension(Configurable):
         config=True,
         help="The base URL for the lab file version management service (AKA Atlas)"
   )
+  sn_file_library_url = Unicode(
+        default_value=os.environ.get("SN_FILE_LIBRARY_URL", "https://author-ide.skills.network/file-library"),
+        config=True,
+        help="The URL for the sn-file-library ui"
+  )
 
 
 def _load_jupyter_server_extension(server_app):
