@@ -4,6 +4,7 @@ import { KernelSpecAPI } from '@jupyterlab/services';
 
 interface Configuration {
 	ATLAS_BASE_URL: string;
+  SN_FILE_LIBRARY_URL: string;
 }
 
 const getServerBaseUrl = (settings: ServerConnection.ISettings): string => {
@@ -35,7 +36,31 @@ export const ATLAS_BASE_URL = await (async (): Promise<string> => {
       = (await response.json()) as Configuration;
 		return configuration.ATLAS_BASE_URL;
   } else {
-    return baseUrl
+    return decodeURIComponent(baseUrl)
+  }
+})();
+
+export const SN_FILE_LIBRARY_URL = await (async (): Promise<string> => {
+	const currentUrl = window.location.href;
+
+	const parameters = new URL(currentUrl).searchParams;
+	const snFileLibraryURL: string | undefined = parameters.get('sn_file_library_url')!;
+	if (snFileLibraryURL === null) {
+		const init: RequestInit = {
+			method: 'GET',
+		};
+		const settings = ServerConnection.makeSettings();
+		const requestUrl = getServerBaseUrl(settings) + 'skillsnetwork-authoring-extension/config';
+    const response = await ServerConnection.makeRequest(
+			requestUrl,
+			init,
+			settings,
+		);
+		const configuration: Configuration
+      = (await response.json()) as Configuration;
+		return configuration.SN_FILE_LIBRARY_URL;
+  } else {
+    return decodeURIComponent(snFileLibraryURL)
   }
 })();
 
@@ -44,42 +69,50 @@ export const ATLAS_BASE_URL = await (async (): Promise<string> => {
  *
  * @returns token
  */
-export const ATLAS_TOKEN = async (): Promise<string> => {
+ export const MODE = async (): Promise<string> => {
 
   const currentURL = window.location.href;
   const params = new URL(currentURL).searchParams;
-  let token: string | null = params.get('token');
-  Globals.LAB_TOOL_TYPE = 'JUPYTER_LITE';
+  let mode: string | null = params.get('mode');
 
-  if (token === null) {
-    // Try getting it from cookie
-    const COOKIE_NAME: string = process.env.ATLAS_TOKEN_COOKIE_NAME ?? 'atlas_token';
-    const reg: RegExp = new RegExp(`(^| )${COOKIE_NAME}=([^;]+)`);
-    let match = reg.exec(document.cookie);
-    // If found then set that as our token o/w set it as empty str for now
-    (match !== null) ? token = match[2] : token = 'NO_TOKEN'
-    Globals.LAB_TOOL_TYPE = 'JUPYTER_LAB';
+  return mode == "learn" ? mode : "author";
+};
+
+
+/**
+ * Extracts the session token. Will first try to get a token via the URL, if none was found then try to get the token via cookie.
+ *
+ * @returns token
+ */
+export const extractAtlasTokenFromQuery = async (): Promise<string> => {
+  const currentURL = window.location.href;
+  const params = new URL(currentURL).searchParams;
+  const token_from_query = params.get('atlas_token')
+
+  return  (token_from_query !== null) ? token_from_query : 'NO_TOKEN';
+};
+
+export const SET_DEFAULT_LAB_NAME_AND_KERNEL = async (): Promise<string> => {
+const currentURL = window.location.href;
+  const params = new URL(currentURL).searchParams;
+  let env_type = params.get('env_type')
+
+  if (env_type !== "jupyterlab" && env_type !== "jupyterlite"){
+    env_type = "local"
   }
 
-  if (token === null || token === 'NO_TOKEN'){
-    // If no token was found in the URL or cookies, the author is in their local env (hopefully...)
-    Globals.AUTHOR_ENV = 'local'
-  }else{
-    Globals.AUTHOR_ENV = 'browser'
-  }
+  console.log("Env type: ", env_type)
 
-  if (Globals.LAB_TOOL_TYPE === 'JUPYTER_LAB') {
+  if (env_type === 'jupyterlab' || env_type === "local") {
     // In production, jupyterlab doesn't have python3 as a kernel option so use python
     Globals.PY_KERNEL_NAME = await GET_PYKERNEL();
     Globals.DEFAULT_LAB_NAME = 'lab.ipynb';
-  }else if (Globals.LAB_TOOL_TYPE === 'JUPYTER_LITE'){
+  } else if (env_type === 'jupyterlite'){
     Globals.PY_KERNEL_NAME = 'python'
     Globals.DEFAULT_LAB_NAME = 'lab.jupyterlite.ipynb';
   }
-
-  Globals.TOKEN = token;
-  return token;
-};
+  return env_type
+}
 
 /**
  * Gets the python kernel. If more than one python kernel is found, prioritize python3. If only one python kernel is found, select that kernel
@@ -108,9 +141,8 @@ export var source = CancelToken.source();
 
 // Global variables
 export class Globals {
-  public static TOKEN: string;
-  public static AUTHOR_ENV: string;
-  public static LAB_TOOL_TYPE: string;
+  public static TOKENS: Map<string, string> = new Map<string, string>();
   public static PY_KERNEL_NAME: string;
   public static DEFAULT_LAB_NAME: string;
+  public static SHOW_PUBLISH_BUTTON_FOR: string | undefined = undefined;
 }
