@@ -3,9 +3,9 @@ import { Dialog } from '@jupyterlab/apputils';
 import { Globals, SN_FILE_LIBRARY_URL } from './config';
 
 export class SkillsNetworkFileLibraryWidget extends Widget {
-    constructor() {
+    constructor(nbPanelId: string) {
       const frame = document.createElement('iframe');
-      frame.src = `${SN_FILE_LIBRARY_URL}?atlas_token=${Globals.TOKEN}`
+      frame.src = `${SN_FILE_LIBRARY_URL}?atlas_token=${Globals.TOKENS.get(nbPanelId)}`
       frame.setAttribute("frameborder", "0")
       frame.setAttribute("allow", "clipboard-read; clipboard-write")
       frame.classList.add("sn-file-library-frame");
@@ -14,9 +14,15 @@ export class SkillsNetworkFileLibraryWidget extends Widget {
 }
 
 export class SkillsNetworkFileLibrary {
+    #nbPanelId: string;
+
+    constructor(nbPanelId: string) {
+      this.#nbPanelId = nbPanelId;
+    }
+
     launch(){
       const imgLibDialog = new Dialog({title: "Skills Network File Library",
-        body:  new SkillsNetworkFileLibraryWidget(),
+        body:  new SkillsNetworkFileLibraryWidget(this.#nbPanelId),
         hasClose: true,
         buttons: []
       });
